@@ -1,18 +1,4 @@
-"""Custom exception definition(necessary for RegistryManager)."""
-
-
-class NoVersionsOnStage(Exception):
-    """Define No Version On Stage Exception."""
-
-    def __init__(self, model_name: str, stage: str):
-        self.model_name = model_name
-        self.stage = stage
-        self.message = f'There is no model "{self.model_name}" on stage "{self.stage}"'
-        super().__init__(self.message)
-
-    def __reduce__(self):
-        """Define reduce method to make exception picklable."""
-        return (NoVersionsOnStage, (self.model_name, self.stage))
+"""Custom exception definition (necessary for RegistryManager)."""
 
 
 class VersionNotFound(Exception):
@@ -28,7 +14,7 @@ class VersionNotFound(Exception):
 
     def __reduce__(self):
         """Define reduce method to make exception picklable."""
-        return (NoVersionsOnStage, (self.model_name, self.version))
+        return (VersionNotFound, (self.model_name, self.version))
 
 
 class MetricNotLogged(Exception):
